CursorDirection

Enum CursorDirection 

pub enum CursorDirection {
    Next,
    NextUnique,
    Prev,
    PrevUnique,
}
Specifies the cursor direction.

Variants



Next

Next causes the cursor to be opened at the start of the source. When iterated, the cursor yields all records, including duplicates, in monotonically increasing order of keys.



NextUnique

NextUnique causes the cursor to be opened at the start of the source. When iterated, the cursor does not yield records with the same key, but otherwise yields all records, in monotonically increasing order of keys.



Prev

Prev causes the cursor to be opened at the end of the source. When iterated, the cursor yields all records, including duplicates, in monotonically decreasing order of keys.



PrevUnique

PrevUnique causes the cursor to be opened at the end of the source. When iterated, the cursor does not yield records with the same key, but otherwise yields all records, in monotonically decreasing order of keys.