Request

Trait Request 

pub trait Request {
    // Required methods
    fn result(&self) -> Result<JsValue, Error>;
    fn error(&self) -> Result<Option<DomException>, Error>;
    fn source(&self) -> Result<Object, Error>;
    fn transaction(&self) -> Option<Transaction>;
    fn ready_state(&self) -> Result<RequestReadyState, Error>;
    fn on_success<F>(&mut self, callback: F)
       where F: FnOnce(Event) + 'static;
    fn on_error<F>(&mut self, callback: F)
       where F: FnOnce(Event) + 'static;
}
Specifies all the functions supported by request objects.

Required Methods

fn result(&self) -> Result<JsValue, Error>

When a request is completed, returns the result, or undefined if the request failed. Returns an Error if the request is still pending.

fn error(&self) -> Result<Option<DomException>, Error>

When a request is completed, returns the error (a DOMException), or None if the request succeeded. Returns an Error if the request is still pending.

fn source(&self) -> Result<Object, Error>

Returns the ObjectStore, Index, or Cursor the request was made against, or null if it was an open request.

fn transaction(&self) -> Option<Transaction>

Returns the Transaction the request was made within. If this as an open request, then it returns an upgrade transaction while it is running, or None otherwise.

fn ready_state(&self) -> Result<RequestReadyState, Error>

Returns RequestReadyState::Pending until a request is complete, then returns RequestReadyState::Done.

fn on_success<F>(&mut self, callback: F)
where F: FnOnce(Event) + 'static,

Adds an event handler for success event.

fn on_error<F>(&mut self, callback: F)
where F: FnOnce(Event) + 'static,

Adds an event handler for error event.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors